@@ -259,6 +259,19 @@ class OpenSesameIDE(BaseExtension):
             always_show=True
         )
 
+    def _run_project_file(self, project_file):
+
+        if u'kernel' in project_file:
+            self.extension_manager.fire(
+                u'jupyter_start_kernel',
+                kernel=project_file['kernel']
+            )
+        self.extension_manager.fire(
+            u'jupyter_run_code',
+            code=project_file.get(u'run', u'')
+        )
+        return
+
     def run_current_file(self):
 
         editor = self._current_editor()
@@ -273,12 +286,9 @@ class OpenSesameIDE(BaseExtension):
                     cfg.opensesame_ide_run_autosave = True
             self.save_file()
         project_file = self._current_project_file()
-        if project_file is not None and u'run' in project_file:
+        if project_file:
             self._run_notify(_(u'Running project'))
-            self.extension_manager.fire(
-                u'jupyter_run_code',
-                code=project_file[u'run']
-            )
+            self._run_project_file(project_file)
             return
         if (
             editor is None or
@@ -457,6 +467,11 @@ class OpenSesameIDE(BaseExtension):
         self._remember_open_folders()
         self._add_recent_folder(path)
 
+    def close_all_folders(self):
+
+        for dockwidget in list(self._dock_widgets.values()):
+            dockwidget.close()
+
     def locate_file_in_folder(self):
 
         for dockwidget in self._dock_widgets.values():
@@ -529,11 +544,20 @@ class OpenSesameIDE(BaseExtension):
 
         def inner(widget, *args, **kwargs):
 
+            # We automatically enable one-tab mode if only the rapunzel tab is
+            # shown, so that we don't have two layers of tabs.
             if (
                 self.tabwidget.count() == 1 and
                 self.main_window.ui.action_onetabmode.isChecked()
             ):
                 self.main_window.ui.action_onetabmode.trigger()
+            # The runner options are not applicable to rapunzel, so we hide
+            # those from the preferences tab.
+            if (
+                hasattr(widget, 'tab_name') and
+                widget.tab_name == '__preferences__'
+            ):
+                widget.ui.groupbox_runner.hide()
             return fnc(widget, *args, **kwargs)
 
         return inner
